@@ -10,7 +10,6 @@ def exp_fit(timewindow, ODwindow):
 
     time: array of time values in hours
     OD: array of OD values
-
     returns: N0, r
     """
 
@@ -73,7 +72,6 @@ def plot_tube(pe, tube, log_OD=None, log_pumps=None, plot_growth_rate=True, wind
     time, od = df.index, df.values.astype(float)
     time0 = time[0]
     time_last = time[-1]
-    od -= od[:10].mean()
 
     time_in_hours = [t.total_seconds() / 3600 for t in time - time0]
 
@@ -119,8 +117,9 @@ def plot_tube(pe, tube, log_OD=None, log_pumps=None, plot_growth_rate=True, wind
         ax3.yaxis.set_ticks_position("left")
 
         ax3.plot(time_in_hours, growth_rates, "r.", alpha=0.03, label="growth rate", markersize=3)
-        growth_rates_mean = np.convolve(growth_rates, [1 / 120] * 120, mode='same')
-        ax3.plot(time_in_hours, growth_rates_mean, 'r--')
+        if len(growth_rates)>120:
+            growth_rates_mean = np.convolve(growth_rates, [1 / 120] * 120, mode='same')
+            ax3.plot(time_in_hours, growth_rates_mean, 'r--')
         ax3.set_ylabel("Growth rate [1/h]")
         ax3.set_ylim(-0.05, 1.6)
         handles3, labels3 = ax3.get_legend_handles_labels()
